@@ -59,6 +59,9 @@ class MPLS (NLRI,CIDR):
 	def __ne__ (self, other):
 		return not self.__eq__(other)
 
+	def __hash__ (self):
+		return hash(self.pack())
+
 	def json (self, announced=True):
 		label = self.labels.json()
 		rdist = self.rd.json()
